function plotter_2(fval)
% PLOTTER_2 Generates and saves statistical plots from simulation data.
%
% This function receives the input data produced from the simulation in 
% the format of a MATLAB table and produces the corresponding figures and 
% statistics. The generated plots are saved in a timestamped folder within 
% the "results" directory.
%
% INPUT:
%   fval - A matrix where:
%       Column 1 contains the Connection Costs.
%       Column 2 contains the Lengths.
%
% OUTPUT:
%   The function saves the generated plots as PNG and EPS files in a
%   timestamped folder within the "results" directory.
%
% USAGE:
%   plotter_2(fval)
%
% EXAMPLE:
%   % Assuming fval is already loaded in the workspace
%   plotter_2(fval)

current_folder = string(datestr(datetime('now'),'dd_mm_yyyy hh_MM_ss'));
mkdir("results" + filesep + current_folder);
folder_layout = "results" + filesep + current_folder;




%% Plot the statistical data out of the experiment
close all 
fig3 = figure(3)
scatter(fval(:,2),fval(:,1))
header = " Monte Carlo Solution space ";
title(header,"Interpreter","None",'FontSize',15) %alternatives could be latex, tex
xlabel('Length [m]','Interpreter','latex')
ylabel('Connection Costs','Interpreter','latex')
full_file = fullfile(folder_layout,"_scatter_plot.png");
full_file_1 = fullfile(folder_layout,"_scatter_plot.eps");
exportgraphics(gcf, full_file);
exportgraphics(gcf,full_file_1,'ContentType','vector','Resolution',600 );

%% script for histogram with variable log. arch. 

close all

t = tiledlayout(1,2,'TileSpacing','compact')


nexttile(1)
%yyaxis left
h = histogram(fval(:,2),'Normalization','pdf') %Distribution of length
xlabel('Length [m]','Interpreter','latex','FontSize',10);

h.FaceColor = [0 0.5 0.5];
h.EdgeColor = 'r'
hold on
nexttile(2)
h2 = histogram(fval(:,1),'Normalization','pdf')
h2.FaceColor = [0 0.5 0.5];
h2.EdgeColor = 'r';
xlabel('Connection costs ','Interpreter','latex','FontSize',10);
ylabel(t,'Probablility Density Fuction','interpreter','latex','fontsize',10)
full_file = fullfile(folder_layout,"_normal_histo.png");
full_file_1 = fullfile(folder_layout,"_normal_histo.eps");
exportgraphics(gcf, full_file);
exportgraphics(gcf,full_file_1,'ContentType','vector','Resolution',600 );

end